@@ -1,32 +1,6 @@
 
 #### Supervised Dimension Projection #####
 
-#' Takes all words as input and arrange them in column with an accompanying column with frequency.
-#' @param words Words
-#' @return Column with all words and an accompanying column with their frequency.
-#' @importFrom tibble as_tibble
-#' @noRd
-unique_freq_words <- function(words) {
-  # Make all words lower case
-  words <- tolower(words)
-
-  # separate words/tokens ombined with /
-  words <- gsub("/", " ", words)
-
-  # Tokenize with nltk
-  nltk <- reticulate::import("nltk")
-  tokenizerNLTK <- nltk$tokenize$word_tokenize
-  words_group <- unlist(lapply(words, tokenizerNLTK))
-
-  words_groupb <- tibble::as_tibble(words_group)
-  sort(words_groupb$value)
-  words_groupb <- table(words_groupb)
-  words_groupb_freq <- tibble::as_tibble(words_groupb, .name_repair = make.names)
-  colnames(words_groupb_freq) <- c("words", "n")
-  words_groupb_freq
-}
-
-
 #' Creates the plot object (except for the legend).
 #' @return A plot object.
 #' @noRd
@@ -298,6 +272,10 @@ textLegend <- function(bivariate_color_codes = bivariate_color_codes,
   legend
 }
 
+
+
+
+
 #' Computes the dot product projection for added data.
 #' @return Word_data_all_yadjusted with added information for the added words.
 #' @noRd
@@ -322,28 +300,40 @@ textOwnWordsProjection <- function(word_data = word_data,
     # If using a contextualized language model
     if (is.null(space) == TRUE) {
 
-
       # Creating word embeddings for the words.
       model_text <- sub(".*model: ", "", text_plot_comment)
-      model_name <- sub(" layer.*", "", model_text)
+      model_name <- sub(" ;.*", "", model_text)
       layers_text <- sub(".*layers: ", "", text_plot_comment)
-      layers_number <- sub(" . textEmbedLayerAggregation.*", "", layers_text)
+      layers_number <- sub(" ;.*", "", layers_text)
       layers_number_split <- stringi::stri_split_boundaries(layers_number,
         type = "word",
         skip_word_none = TRUE,
         skip_word_number = FALSE
       )
 
+      #
+      aggregate_layers_text <- sub(".*aggregation_from_layers_to_tokens =  ", "", text_plot_comment)
+      aggregate_layers_type <- sub(" aggregation_from_tokens_to_texts.*", "", aggregate_layers_text)
+
+      aggregation_tokens_text <- sub(".*aggregation_from_tokens_to_texts =  ", "", text_plot_comment)
+      aggregation_tokens_type <- sub(" tokens_select.*", "", aggregation_tokens_text)
+
+      aggregation_word_text <- sub(".*aggregation_from_tokens_to_word_types =  ", "", text_plot_comment)
+      aggregation_word_type <- sub("  ; decontextualize.*", "", aggregation_word_text)
+
       explore_words_embeddings <- textEmbed(explore_words[i_add_w],
         model = model_name,
-        layers = dput(as.numeric(layers_number_split[[1]]))
+        layers = as.numeric(layers_number_split[[1]]),
+        aggregation_from_layers_to_tokens = aggregate_layers_type,
+        aggregation_from_tokens_to_texts = aggregation_tokens_type,
+        aggregation_from_tokens_to_word_types = aggregation_word_type
       )
     }
     # If using a static/decontextualized language model
     if (!is.null(space) == TRUE) {
       explore_words_embeddings <- textEmbedStatic(data.frame(explore_words[i_add_w]),
         space = space,
-        aggregate = explore_words_aggregation
+        aggregation_from_tokens_to_texts = explore_words_aggregation
       )
     }
 
@@ -354,7 +344,7 @@ textOwnWordsProjection <- function(word_data = word_data,
 
     # Scaling embeddings before aggregation
     if (scaling == TRUE) {
-      singlewords_we_x <- dplyr::select(explore_words_embeddings$singlewords_we, dplyr::starts_with("Dim"))
+      singlewords_we_x <- dplyr::select(explore_words_embeddings$word_types, dplyr::starts_with("Dim"))
 
       # Applying scaling parameters to all the unique word's embeddings
       scale_center_weights <- word_data$background[[1]]$scale_centre.x %>%
@@ -365,7 +355,7 @@ textOwnWordsProjection <- function(word_data = word_data,
 
       singlewords_we_x_scaled <- tibble::as_tibble((singlewords_we_x - scale_center_weights) / scale_scale_weights)
 
-      singlewords_we_x_scaled_w_n <- bind_cols(explore_words_embeddings$singlewords_we[1:2], singlewords_we_x_scaled)
+      singlewords_we_x_scaled_w_n <- bind_cols(explore_words_embeddings$word_types[1:2], singlewords_we_x_scaled)
 
       #### Create token and aggregated word embeddings ####
       # Aggregate the words
@@ -378,13 +368,13 @@ textOwnWordsProjection <- function(word_data = word_data,
     } else {
       # Aggregate the words
       Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(
-        explore_words_embeddings$singlewords_we,
+        explore_words_embeddings$word_types,
         dplyr::starts_with("Dim")
       ),
       aggregation = explore_words_aggregation
       ))
       Mean1 <- dplyr::bind_cols(words, n_words, Aggregated_embedding_added_words)
-      manual_words_mean1 <- bind_rows(explore_words_embeddings$singlewords_we, Mean1)
+      manual_words_mean1 <- bind_rows(explore_words_embeddings$word_types, Mean1)
     }
 
     #### Project embedding on the x axes ######
@@ -498,6 +488,7 @@ textOwnWordPrediction <- function(word_data = word_data,
   forloops_add_w <- length(explore_words)
   added_words_information <- list()
 
+
   for (i_add_w in 1:forloops_add_w) {
 
     # If using a contextualized language model
@@ -505,25 +496,38 @@ textOwnWordPrediction <- function(word_data = word_data,
 
       # Creating word embeddings for the words.
       model_text <- sub(".*model: ", "", text_plot_comment)
-      model_name <- sub(" layer.*", "", model_text)
+      model_name <- sub(" ; layer.*", "", model_text)
       layers_text <- sub(".*layers: ", "", text_plot_comment)
-      layers_number <- sub(" . textEmbedLayerAggregation.*", "", layers_text)
+      layers_number <- sub(" ; word_type_embeddings.*", "", layers_text)
       layers_number_split <- stringi::stri_split_boundaries(layers_number,
         type = "word",
         skip_word_none = TRUE,
         skip_word_number = FALSE
       )
 
+      #
+      aggregate_layers_text <- sub(".*aggregation_from_layers_to_tokens =  ", "", text_plot_comment)
+      aggregate_layers_type <- sub(" aggregation_from_tokens_to_texts.*", "", aggregate_layers_text)
+
+      aggregation_tokens_text <- sub(".*aggregation_from_tokens_to_texts =  ", "", text_plot_comment)
+      aggregation_tokens_type <- sub(" tokens_select.*", "", aggregation_tokens_text)
+
+      aggregation_word_text <- sub(".*aggregation_from_tokens_to_word_types =  ", "", text_plot_comment)
+      aggregation_word_type <- sub("  ; decontextualize.*", "", aggregation_word_text)
+
       explore_words_embeddings <- textEmbed(explore_words[i_add_w],
         model = model_name,
-        layers = dput(as.numeric(layers_number_split[[1]]))
+        layers = as.numeric(layers_number_split[[1]]),
+        aggregation_from_layers_to_tokens = aggregate_layers_type,
+        aggregation_from_tokens_to_texts = aggregation_tokens_type,
+        aggregation_from_tokens_to_word_types = aggregation_word_type
       )
     }
     # If using a static/decontextualized language model
     if (!is.null(space) == TRUE) {
       explore_words_embeddings <- textEmbedStatic(data.frame(explore_words[i_add_w]),
         space = space,
-        aggregate = explore_words_aggregation
+        aggregation_from_tokens_to_texts = explore_words_aggregation
       )
     }
 
@@ -535,13 +539,13 @@ textOwnWordPrediction <- function(word_data = word_data,
 
     # Aggregate the words
     Aggregated_embedding_added_words <- tibble::as_tibble_row(textEmbeddingAggregation(dplyr::select(
-      explore_words_embeddings$singlewords_we,
+      explore_words_embeddings$word_types,
       dplyr::starts_with("Dim")
     ),
     aggregation = explore_words_aggregation
     ))
     Mean1 <- dplyr::bind_cols(words, n_words, Aggregated_embedding_added_words)
-    manual_words_mean1 <- bind_rows(explore_words_embeddings$singlewords_we, Mean1)
+    manual_words_mean1 <- bind_rows(explore_words_embeddings$word_types, Mean1)
 
 
     prediction_x <- textPredict(word_data$model_x, manual_words_mean1)$.pred # , ...
@@ -612,6 +616,7 @@ adjust_for_plot_type <- function(word_data, y_axes) {
   return(word_data)
 }
 
+
 #' Plot words from textProjection() or textWordPrediction().
 #' @param word_data Dataframe from textProjection
 #' @param k_n_words_to_test Select the k most frequent words to significance
@@ -894,7 +899,7 @@ textPlot <- function(word_data,
       purrr::as_vector(word_data1_padjusted_y[, "p_values_y"]),
       method = p_adjust_method
     )
-    word_data1 <- left_join(word_data1, word_data1_padjusted_y[, c("words", "adjusted_p_values.y")], by = "words")
+    word_data1 <- dplyr::left_join(word_data1, word_data1_padjusted_y[, c("words", "adjusted_p_values.y")], by = "words")
   }
 
   # Select only min_freq_words_plot to plot (i.e., after correction of multiple comparison for sig. test)
@@ -1161,7 +1166,7 @@ textPlot <- function(word_data,
   }
 
 
-  ##### Adding/exploring words MANUALY ######
+  ##### Adding/exploring words MANUALY ###### explore_words = "happy"
 
   if (!is.null(explore_words) == TRUE) {
     if (plot_type_name == "textProjection") {
